@@ -122,7 +122,7 @@ func TestBreakdownFormatJsonWithTagsAftModule(t *testing.T) {
 			IsJSON:      true,
 			JSONInclude: regexp.MustCompile("^(defaultTags|tags|name)$"),
 			JSONExclude: regexp.MustCompile("^(costComponents|pastBreakdown)$"),
-			RegexFilter: regexp.MustCompile("(tags-mock|bucket-mock)"),
+			RegexFilter: regexp.MustCompile("(tags-infracost-mock-44956be29f34|bucket-infracost-mock-44956be29f34|name-infracost-mock-44956be29f34)"),
 		}, func(ctx *config.RunContext) {
 			ctx.Config.TagPoliciesEnabled = true
 		},
@@ -750,6 +750,10 @@ func TestBreakdownTerraformUseState_v0_14(t *testing.T) {
 	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"breakdown", "--path", "./testdata/terraform_v0.14_state.json", "--terraform-use-state"}, nil)
 }
 
+func TestBreakdownTerraformTFJSON(t *testing.T) {
+	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"breakdown", "--path", path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())}, nil)
+}
+
 func TestBreakdownWithPrivateTerraformRegistryModule(t *testing.T) {
 	if os.Getenv("INFRACOST_TERRAFORM_CLOUD_TOKEN") == "" {
 		t.Skip("Skipping because INFRACOST_TERRAFORM_CLOUD_TOKEN is not set and external contributors won't have this.")
@@ -1067,6 +1071,42 @@ func TestBreakdownWithOptionalVariables(t *testing.T) {
 	)
 }
 
+func TestBreakdownWithComplexConfigFileVars(t *testing.T) {
+	dir := path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())
+
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--config-file",
+			path.Join(dir, "infracost.yml"),
+		},
+		nil,
+	)
+}
+
+func TestBreakdownWithComplexVarFlags(t *testing.T) {
+	dir := path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())
+
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			dir,
+			"--terraform-var",
+			"instance_config={\"instance_type\":\"t2.micro\",\"storage\":20}",
+			"--terraform-var",
+			"lambda_configs=[{memory_size = 128},{ memory_size = 256}]",
+			"--usage-file",
+			path.Join(dir, "infracost-usage.yml"),
+		},
+		nil,
+	)
+}
+
 func TestBreakdownWithDeepMergeModule(t *testing.T) {
 	GoldenFileCommandTest(
 		t,
