@@ -75,7 +75,7 @@ type Project struct {
 	// TerraformVarFiles is any var files that are to be used with the project.
 	TerraformVarFiles []string `yaml:"terraform_var_files,omitempty"`
 	// TerraformVars is a slice of input vars that are to be used with the project.
-	TerraformVars map[string]string `yaml:"terraform_vars,omitempty"`
+	TerraformVars map[string]interface{} `yaml:"terraform_vars,omitempty"`
 	// TerraformForceCLI will run a project by calling out to the terraform/terragrunt binary to generate a plan JSON file.
 	TerraformForceCLI bool `yaml:"terraform_force_cli,omitempty"`
 	// TerraformPlanFlags are flags to pass to terraform plan with Terraform directory paths
@@ -96,6 +96,14 @@ type Project struct {
 	// TerraformCloudToken sets the Team API Token or User API Token so infracost can use it to access the plan.
 	// Only applicable for terraform cloud/enterprise users.
 	TerraformCloudToken string `yaml:"terraform_cloud_token,omitempty" envconfig:"TERRAFORM_CLOUD_TOKEN"`
+	// SpaceliftAPIKeyEndpoint is the endpoint that the spacelift API client will communicate with.
+	SpaceliftAPIKeyEndpoint string `yaml:"spacelift_api_key_endpoint,omitempty" envconfig:"SPACELIFT_API_KEY_ENDPOINT"`
+	// SpaceliftAPIKeyID is the spacelift API key ID. This is used in combination
+	// with the API key secret to generate a JWT token.
+	SpaceliftAPIKeyID string `yaml:"spacelift_api_key_id,omitempty" envconfig:"SPACELIFT_API_KEY_ID"`
+	// SpaceliftAPIKeySecret is the spacelift API key secret.This is used in combination
+	// with the API key id to generate a JWT token.
+	SpaceliftAPIKeySecret string `yaml:"spacelift_api_key_secret,omitempty" envconfig:"SPACELIFT_API_KEY_SECRET"`
 	// TerragruntFlags set additional flags that should be passed to terragrunt.
 	TerragruntFlags string `yaml:"terragrunt_flags,omitempty" envconfig:"TERRAGRUNT_FLAGS"`
 	// UsageFile is the full path to usage file that specifies values for usage-based resources
@@ -103,6 +111,8 @@ type Project struct {
 	// TerraformUseState sets if the users wants to use the terraform state for infracost ops.
 	TerraformUseState bool              `yaml:"terraform_use_state,omitempty" ignored:"true"`
 	Env               map[string]string `yaml:"env,omitempty" ignored:"true"`
+	// YorConfigPath is the path to a Yor config file, which we can extract default tags from
+	YorConfigPath string `yaml:"yor_config_path,omitempty" ignored:"true"`
 }
 
 type Config struct {
