@@ -13,6 +13,8 @@ import (
 	"github.com/pkg/errors"
 	pathToRegexp "github.com/soongo/path-to-regexp"
 	"gopkg.in/yaml.v2"
+
+	"github.com/infracost/infracost/internal/logging"
 )
 
 var (
@@ -34,6 +36,7 @@ type DetectedRooModule struct {
 
 // Variables hold the global variables that are passed into any template that the Parser evaluates.
 type Variables struct {
+	RepoName            string
 	Branch              string
 	BaseBranch          string
 	DetectedProjects    []DetectedProject
@@ -62,6 +65,11 @@ func NewParser(repoDir string, variables Variables) *Parser {
 		"startsWith": p.startsWith,
 		"endsWith":   p.endsWith,
 		"contains":   p.contains,
+		"trimPrefix": p.trimPrefix,
+		"trimSuffix": p.trimSuffix,
+		"replace":    p.replace,
+		"quote":      p.quote,
+		"squote":     p.squote,
 		"pathExists": p.pathExists,
 		"matchPaths": p.matchPaths,
 		"list":       p.list,
@@ -152,6 +160,45 @@ func (p *Parser) contains(s, substr string) bool {
 	return strings.Contains(s, substr)
 }
 
+// trimPrefix returns s without the provided prefix string.
+func (p *Parser) trimPrefix(s, prefix string) string {
+	return strings.TrimPrefix(s, prefix)
+}
+
+// trimSuffix returns s without the provided suffix string.
+func (p *Parser) trimSuffix(s, suffix string) string {
+	return strings.TrimSuffix(s, suffix)
+}
+
+// replace returns s with all instances of old replaced by new.
+func (p *Parser) replace(old, new, s string) string {
+	return strings.ReplaceAll(s, old, new)
+}
+
+// quote wraps the provided strings in double quotes.
+// Taken from https://github.com/Masterminds/sprig/blob/581758eb7d96ae4d113649668fa96acc74d46e7f/strings.go#L83
+func (p *Parser) quote(str ...interface{}) string {
+	out := make([]string, 0, len(str))
+	for _, s := range str {
+		if s != nil {
+			out = append(out, fmt.Sprintf("%q", strval(s)))
+		}
+	}
+	return strings.Join(out, " ")
+}
+
+// squote wraps the provided strings in single quotes.
+// Taken from https://github.com/Masterminds/sprig/blob/581758eb7d96ae4d113649668fa96acc74d46e7f/strings.go#L93C1-L101C2
+func (p *Parser) squote(str ...interface{}) string {
+	out := make([]string, 0, len(str))
+	for _, s := range str {
+		if s != nil {
+			out = append(out, fmt.Sprintf("'%v'", s))
+		}
+	}
+	return strings.Join(out, " ")
+}
+
 // pathExists reports whether path is a subpath within base.
 func (p *Parser) pathExists(base, path string) bool {
 	if !filepath.IsAbs(base) {
@@ -297,11 +344,12 @@ func (p *Parser) readFile(path string) string {
 
 // parseYaml decodes provided yaml contents and assigns decoded values into a
 // generic out value. This can be used as a simple object in the templates.
+// This returns an empty map if the yaml is invalid.
 func (p *Parser) parseYaml(contents string) map[string]interface{} {
 	var out map[string]interface{}
 	err := yaml.Unmarshal([]byte(contents), &out)
 	if err != nil {
-		panic(err)
+		logging.Logger.Error().Err(err).Msg("failed to unmarshal yaml when calling parseYaml in the config template")
 	}
 
 	return out
@@ -309,11 +357,12 @@ func (p *Parser) parseYaml(contents string) map[string]interface{} {
 
 // parseJson decodes the provided json contents and assigns decoded values into a
 // generic out value. This can be used as a simple object in the templates.
+// This returns an empty map if the json is invalid.
 func (p *Parser) parseJson(contents string) map[string]interface{} {
 	var out map[string]interface{}
 	err := jsoniter.Unmarshal([]byte(contents), &out)
 	if err != nil {
-		panic(err)
+		logging.Logger.Error().Err(err).Msg("failed to unmarshal json when calling parseJson in the config template")
 	}
 
 	return out
@@ -343,3 +392,20 @@ func isSubdirectory(base, target string) bool {
 
 	return !strings.HasPrefix(relPath, "..") && fileInfo.Mode()&os.ModeSymlink == 0
 }
+
+// strval returns the string representation of v.
+// Taken from https://github.com/Masterminds/sprig/blob/581758eb7d96ae4d113649668fa96acc74d46e7f/strings.go#L174
+func strval(v interface{}) string {
+	switch v := v.(type) {
+	case string:
+		return v
+	case []byte:
+		return string(v)
+	case error:
+		return v.Error()
+	case fmt.Stringer:
+		return v.String()
+	default:
+		return fmt.Sprintf("%v", v)
+	}
+}
