@@ -838,7 +838,7 @@ func (b *Block) Children() Blocks {
 		children = append(children, child)
 	}
 
-	return b.childBlocks
+	return children
 }
 
 // GetAttributes returns a list of Attribute for this Block. Attributes are key value specification on a given
@@ -1030,7 +1030,7 @@ func (b *Block) getHCLAttributes() hcl.Attributes {
 			return nil
 		}
 		for k := range attrs {
-			if _, ok := b.UniqueAttrs[k]; !ok {
+			if _, ok := b.UniqueAttrs[k]; ok {
 				delete(attrs, k)
 			}
 
@@ -1065,6 +1065,24 @@ func (b *Block) Values() cty.Value {
 	return b.values()
 }
 
+type AttributeWithUnknownKeys struct {
+	Attribute        string   `json:"attribute"`
+	MissingVariables []string `json:"missingVariables"`
+}
+
+func (b *Block) AttributesWithUnknownKeys() []AttributeWithUnknownKeys {
+	var output []AttributeWithUnknownKeys
+	for _, attr := range b.attributes {
+		if causes := attr.ReferencesCausingUnknownKeys(); len(causes) > 0 {
+			output = append(output, AttributeWithUnknownKeys{
+				Attribute:        attr.Name(),
+				MissingVariables: causes,
+			})
+		}
+	}
+	return output
+}
+
 func (b *Block) values() cty.Value {
 	values := make(map[string]cty.Value)
 
@@ -1379,6 +1397,10 @@ func launchTemplateValues(b *Block) cty.Value {
 	v, ok := launchTemplateData["name"]
 
 	if !ok || v.IsNull() {
+		if launchTemplateData == nil {
+			launchTemplateData = make(map[string]cty.Value)
+		}
+
 		h := sha256.New()
 		h.Write([]byte(b.FullName()))
 		addressSha := hex.EncodeToString(h.Sum(nil))
