@@ -104,7 +104,7 @@ func mergeVars(src cty.Value, parts []string, value cty.Value) cty.Value {
 	data := make(map[string]cty.Value)
 	if src.Type().IsObjectType() && !src.IsNull() && src.LengthInt() > 0 {
 		data = src.AsValueMap()
-		tmp, ok := data[parts[0]]
+		tmp, ok := data[parts[0]] // nolint:gosec // ignore "G602: slice index out of range" since we already check len(parts) == 0
 		if !ok {
 			src = cty.ObjectVal(make(map[string]cty.Value))
 		} else {
@@ -112,7 +112,7 @@ func mergeVars(src cty.Value, parts []string, value cty.Value) cty.Value {
 		}
 	}
 
-	data[parts[0]] = mergeVars(src, parts[1:], value)
+	data[parts[0]] = mergeVars(src, parts[1:], value) // nolint:gosec // ignore "G602: slice index out of range" since we already check len(parts) == 0
 
 	return cty.ObjectVal(data)
 }
