@@ -165,14 +165,20 @@ func OptionWithPlanFlagVars(vs []string) Option {
 
 // OptionWithInputVars takes cmd line var input values and converts them to cty.Value
 // It sets these as the Parser starting inputVars which are used at the root module evaluation.
-func OptionWithInputVars(vars map[string]string) Option {
+func OptionWithInputVars(vars map[string]interface{}) Option {
 	return func(p *Parser) {
 		if p.inputVars == nil {
 			p.inputVars = make(map[string]cty.Value, len(vars))
 		}
 
-		for k, v := range vars {
-			p.inputVars[k] = cty.StringVal(v)
+		for k, val := range vars {
+			v, err := ParseVariable(val)
+			if err != nil {
+				p.logger.Debug().Err(err).Msgf("could not parse input var %s", k)
+				continue
+			}
+
+			p.inputVars[k] = v
 		}
 	}
 }
@@ -202,16 +208,41 @@ func OptionWithRawCtyInput(input cty.Value) (op Option) {
 	}
 }
 
-// OptionWithRemoteVarLoader accepts Terraform Cloud/Enterprise host and token
+// OptionWithTFCRemoteVarLoader accepts Terraform Cloud/Enterprise host and token
 // values to load remote execution variables.
-func OptionWithRemoteVarLoader(host, token, localWorkspace string, loaderOpts ...RemoteVariablesLoaderOption) Option {
+func OptionWithTFCRemoteVarLoader(host, token, localWorkspace string, loaderOpts ...TFCRemoteVariablesLoaderOption) Option {
 	return func(p *Parser) {
 		if host == "" || token == "" {
 			return
 		}
 
 		client := extclient.NewAuthedAPIClient(host, token)
-		p.remoteVariablesLoader = NewRemoteVariablesLoader(client, localWorkspace, p.logger, loaderOpts...)
+		p.remoteVariableLoaders = append(p.remoteVariableLoaders, NewTFCRemoteVariablesLoader(client, localWorkspace, p.logger, loaderOpts...))
+	}
+}
+
+// OptionWithSpaceliftRemoteVarLoader attempts to build a SpaceLift remote
+// variable loader and set this on the parser. If the required environment
+// variables are not set, the loader is skipped.
+func OptionWithSpaceliftRemoteVarLoader(ctx *config.ProjectContext) Option {
+	return func(p *Parser) {
+		if ctx.ProjectConfig.SpaceliftAPIKeyEndpoint == "" || ctx.ProjectConfig.SpaceliftAPIKeyID == "" || ctx.ProjectConfig.SpaceliftAPIKeySecret == "" {
+			p.logger.Trace().Msg("Required Spacelift API key environment variables not set, skipping Spacelift remote variable loader.")
+			return
+		}
+
+		loader, err := NewSpaceliftRemoteVariableLoader(
+			ctx.RunContext.VCSMetadata,
+			ctx.ProjectConfig.SpaceliftAPIKeyEndpoint,
+			ctx.ProjectConfig.SpaceliftAPIKeyID,
+			ctx.ProjectConfig.SpaceliftAPIKeySecret,
+		)
+		if err != nil {
+			p.logger.Debug().Err(err).Msg("could not create Spacelift remote variable loader")
+			return
+		}
+
+		p.remoteVariableLoaders = append(p.remoteVariableLoaders, loader)
 	}
 }
 
@@ -265,7 +296,7 @@ type Parser struct {
 	moduleLoader          *modules.ModuleLoader
 	hclParser             *modules.SharedHCLParser
 	blockBuilder          BlockBuilder
-	remoteVariablesLoader *RemoteVariablesLoader
+	remoteVariableLoaders []RemoteVariableLoader
 	logger                zerolog.Logger
 	isGraph               bool
 	hasChanges            bool
@@ -392,8 +423,9 @@ func (p *Parser) DependencyPaths() []string {
 // ParseDirectory returns the root Module that represents the top of the Terraform Config tree.
 func (p *Parser) ParseDirectory() (m *Module, err error) {
 	m = &Module{
-		RootPath:   p.detectedProjectPath,
-		ModulePath: p.detectedProjectPath,
+		RootPath:     p.detectedProjectPath,
+		ModulePath:   p.detectedProjectPath,
+		ModuleSuffix: p.moduleSuffix,
 	}
 
 	defer func() {
@@ -580,15 +612,20 @@ func (p *Parser) loadVars(blocks Blocks, filenames []string) (map[string]cty.Val
 		combinedVars = make(map[string]cty.Value)
 	}
 
-	if p.remoteVariablesLoader != nil {
-		remoteVars, err := p.remoteVariablesLoader.Load(blocks)
-		if err != nil {
-			p.logger.Debug().Msgf("could not load vars from Terraform Cloud: %s", err)
-			return combinedVars, err
-		}
+	if p.remoteVariableLoaders != nil {
+		for _, loader := range p.remoteVariableLoaders {
+			remoteVars, err := loader.Load(RemoteVarLoaderOptions{
+				Blocks:  blocks,
+				EnvName: p.EnvName(),
+			})
+			if err != nil {
+				p.logger.Debug().Msgf("could not load vars from Terraform Cloud: %s", err)
+				return combinedVars, err
+			}
 
-		for k, v := range remoteVars {
-			combinedVars[k] = v
+			for k, v := range remoteVars {
+				combinedVars[k] = v
+			}
 		}
 	}
 
