@@ -102,7 +102,7 @@ func Detect(ctx *config.RunContext, project *config.Project, includePastResource
 		} else {
 			detectedProjectContext.ContextValues.SetValue("project_type", "terraform_dir")
 			if ctx.Config.ConfigFilePath == "" && len(project.TerraformVarFiles) == 0 {
-				autoProviders = append(autoProviders, autodetectedRootToProviders(pl, detectedProjectContext, rootPath)...)
+				autoProviders = append(autoProviders, autodetectedRootToProviders(detectedProjectContext, rootPath)...)
 			} else {
 				autoProviders = append(autoProviders, configFileRootToProvider(rootPath, nil, detectedProjectContext, pl))
 			}
@@ -144,7 +144,7 @@ func configFileRootToProvider(rootPath hcl.RootPath, options []hcl.Option, proje
 // autodetectedRootToProviders returns a list of providers for the given root
 // path. These providers are generated by autodetected environments defined in
 // the root module. These are defined by var file naming conventions.
-func autodetectedRootToProviders(pl *hcl.ProjectLocator, projectContext *config.ProjectContext, rootPath hcl.RootPath, options ...hcl.Option) []schema.Provider {
+func autodetectedRootToProviders(projectContext *config.ProjectContext, rootPath hcl.RootPath, options ...hcl.Option) []schema.Provider {
 	var providers []schema.Provider
 	autoVarFiles := rootPath.AutoFiles()
 	autoVarFiles = append(autoVarFiles, rootPath.GlobalFiles()...)
