@@ -10,6 +10,17 @@ func getDXGatewayAssociationRegistryItem() *schema.RegistryItem {
 		Name:                "aws_dx_gateway_association",
 		CoreRFunc:           NewDXGatewayAssociation,
 		ReferenceAttributes: []string{"associated_gateway_id"},
+		GetRegion: func(defaultRegion string, d *schema.ResourceData) string {
+			assocGateway := d.References("associated_gateway_id")
+			if len(assocGateway) > 0 {
+				region := assocGateway[0].Get("region").String()
+				if region != "" {
+					return region
+				}
+			}
+
+			return defaultRegion
+		},
 	}
 }
 func NewDXGatewayAssociation(d *schema.ResourceData) schema.CoreResource {
