@@ -7,12 +7,12 @@ import (
 
 func getFSxWindowsFSRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_fsx_windows_file_system",
-		Notes: []string{"Data deduplication is not supported by Terraform."},
-		RFunc: NewFSxWindowsFileSystem,
+		Name:      "aws_fsx_windows_file_system",
+		Notes:     []string{"Data deduplication is not supported by Terraform."},
+		CoreRFunc: NewFSxWindowsFileSystem,
 	}
 }
-func NewFSxWindowsFileSystem(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewFSxWindowsFileSystem(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.FSxWindowsFileSystem{
 		Address:            d.Address,
 		Region:             d.Get("region").String(),
@@ -21,7 +21,5 @@ func NewFSxWindowsFileSystem(d *schema.ResourceData, u *schema.UsageData) *schem
 		ThroughputCapacity: d.Get("throughput_capacity").Int(),
 		StorageCapacityGB:  d.Get("storage_capacity").Int(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
