@@ -7,18 +7,17 @@ import (
 
 func getGlueCatalogDatabaseRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_glue_catalog_database",
-		RFunc: newGlueCatalogDatabase,
+		Name:      "aws_glue_catalog_database",
+		CoreRFunc: newGlueCatalogDatabase,
 	}
 }
 
-func newGlueCatalogDatabase(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func newGlueCatalogDatabase(d *schema.ResourceData) schema.CoreResource {
 	region := d.Get("region").String()
 	r := &aws.GlueCatalogDatabase{
 		Address: d.Address,
 		Region:  region,
 	}
-	r.PopulateUsage(u)
 
-	return r.BuildResource()
+	return r
 }
