@@ -18,16 +18,17 @@ func getInstanceRegistryItem() *schema.RegistryItem {
 			"EC2 detailed monitoring assumes the standard 7 metrics and the lowest tier of prices for CloudWatch.",
 			"If a root volume is not specified then an 8Gi gp2 volume is assumed.",
 		},
-		RFunc: NewInstance,
+		CoreRFunc: NewInstance,
 		ReferenceAttributes: []string{
 			"ebs_block_device.#.volume_id",
+			"host_id",
 			"launch_template.#.id",
 			"launch_template.#.name",
 		},
 	}
 }
 
-func NewInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewInstance(d *schema.ResourceData) schema.CoreResource {
 	region := d.Get("region").String()
 
 	purchaseOption := "on_demand"
@@ -76,6 +77,7 @@ func NewInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
 	monitoring = d.GetBoolOrDefault("monitoring", monitoring)
 	cpuCredits = d.GetStringOrDefault("credit_specification.0.cpu_credits", cpuCredits)
 	tenancy = d.GetStringOrDefault("tenancy", tenancy)
+	hasHost := len(d.References("host_id")) > 0
 
 	a := &aws.Instance{
 		Address:          d.Address,
@@ -87,6 +89,7 @@ func NewInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
 		EBSOptimized:     ebsOptimized,
 		EnableMonitoring: monitoring,
 		CPUCredits:       cpuCredits,
+		HasHost:          hasHost,
 	}
 
 	a.RootBlockDevice = &aws.EBSVolume{
@@ -157,8 +160,5 @@ func NewInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
 		blockDevicesCount++
 	}
 
-	a.PopulateUsage(u)
-
-	return a.BuildResource()
-
+	return a
 }
