@@ -85,12 +85,15 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getRoute53ZoneRegistryItem(),
 	getS3BucketAnalyticsConfigurationRegistryItem(),
 	getS3BucketInventoryRegistryItem(),
+	getS3BucketLifecycleConfigurationRegistryItem(),
 	getS3BucketRegistryItem(),
+	getS3BucketVersioningRegistryItem(),
 	getSecretsManagerSecret(),
 	getSSMActivationRegistryItem(),
 	getSSMParameterRegistryItem(),
 	getSNSTopicRegistryItem(),
 	getSNSTopicSubscriptionRegistryItem(),
+	getSubnetRegistryItem(),
 	getSQSQueueRegistryItem(),
 	getNeptuneClusterRegistryItem(),
 	getNeptuneClusterInstanceRegistryItem(),
@@ -100,6 +103,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getNewEKSClusterItem(),
 	getNewKMSKeyRegistryItem(),
 	getNewKMSExternalKeyRegistryItem(),
+	getVPCRegistryItem(),
 	getVPNConnectionRegistryItem(),
 	getVPCEndpointRegistryItem(),
 	getWAFv2WebACLRegistryItem(),
@@ -115,6 +119,9 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getLambdaProvisionedConcurrencyConfigRegistryItem(),
 	getKinesisStreamRegistryItem(),
 	getCloudHSMv2HSMRegistryItem(),
+	getSchedulerScheduleRegistryItem(),
+	getPipesPipeRegistryItem(),
+	getCloudwatchEventTargetRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -370,7 +377,6 @@ var FreeResources = []string{
 	"aws_cloudwatch_event_connection",
 	"aws_cloudwatch_event_permission",
 	"aws_cloudwatch_event_rule",
-	"aws_cloudwatch_event_target",
 
 	// "AWS Global Accelerator Listener
 	"aws_globalaccelerator_listener",
@@ -535,7 +541,6 @@ var FreeResources = []string{
 	"aws_s3_bucket_public_access_block",
 	"aws_s3_bucket_replication_configuration",
 	"aws_s3_bucket_server_side_encryption_configuration",
-	"aws_s3_bucket_versioning",
 	"aws_s3_bucket_website_configuration",
 	"aws_s3_object", // Costs are shown at the bucket level
 
@@ -602,8 +607,17 @@ var FreeResources = []string{
 
 	// AWS SSO
 	"aws_ssoadmin_account_assignment",
+	"aws_ssoadmin_application",
+	"aws_ssoadmin_application_access_scope",
+	"aws_ssoadmin_application_assignment",
+	"aws_ssoadmin_application_assignment_configuration",
+	"aws_ssoadmin_customer_managed_policy_attachment",
+	"aws_ssoadmin_instance_access_control_attributes",
 	"aws_ssoadmin_managed_policy_attachment",
+	"aws_ssoadmin_permission_set",
 	"aws_ssoadmin_permission_set_inline_policy",
+	"aws_ssoadmin_permissions_boundary_attachment",
+	"aws_ssoadmin_trusted_token_issuer",
 
 	// AWS Transfer Family
 	"aws_transfer_access",
@@ -645,8 +659,6 @@ var FreeResources = []string{
 	"aws_route_table_association",
 	"aws_security_group",
 	"aws_security_group_rule",
-	"aws_subnet",
-	"aws_vpc",
 	"aws_vpc_dhcp_options",
 	"aws_vpc_dhcp_options_association",
 	"aws_vpc_endpoint_connection_notification",
