@@ -7,18 +7,16 @@ import (
 
 func getRoute53ResolverEndpointRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_route53_resolver_endpoint",
-		RFunc: NewRoute53ResolverEndpoint,
+		Name:      "aws_route53_resolver_endpoint",
+		CoreRFunc: NewRoute53ResolverEndpoint,
 	}
 }
 
-func NewRoute53ResolverEndpoint(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewRoute53ResolverEndpoint(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.Route53ResolverEndpoint{
 		Address:           d.Address,
 		Region:            d.Get("region").String(),
 		ResolverEndpoints: int64(len(d.Get("ip_address").Array())),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
