@@ -7,18 +7,16 @@ import (
 
 func getSSMActivationRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_ssm_activation",
-		RFunc: NewSSMActivation,
+		Name:      "aws_ssm_activation",
+		CoreRFunc: NewSSMActivation,
 	}
 }
 
-func NewSSMActivation(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewSSMActivation(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.SSMActivation{
 		Address:           d.Address,
 		Region:            d.Get("region").String(),
 		RegistrationLimit: d.Get("registration_limit").Int(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
