@@ -7,12 +7,11 @@ import (
 
 func getVPNConnectionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_vpn_connection",
-		RFunc: NewVPNConnection,
+		Name:      "aws_vpn_connection",
+		CoreRFunc: NewVPNConnection,
 	}
 }
-func NewVPNConnection(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewVPNConnection(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.VPNConnection{Address: d.Address, TransitGatewayID: d.Get("transit_gateway_id").String(), Region: d.Get("region").String()}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
