@@ -17,7 +17,7 @@ func GetAzureRMHDInsightKafkaClusterRegistryItem() *schema.RegistryItem {
 }
 
 func NewAzureRMHDInsightKafkaCluster(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{})
+	region := d.Region
 
 	costComponents := []*schema.CostComponent{}
 
