@@ -16,7 +16,7 @@ func getMachineLearningComputeClusterRegistryItem() *schema.RegistryItem {
 }
 
 func newMachineLearningComputeCluster(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	return &azure.MachineLearningComputeCluster{
 		Address:      d.Address,
 		Region:       region,
