@@ -27,7 +27,7 @@ func newNetworkConnectionMonitor(d *schema.ResourceData) schema.CoreResource {
 		}
 	}
 
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	return &azure.NetworkConnectionMonitor{
 		Address: d.Address,
 		Region:  region,
