@@ -7,16 +7,15 @@ import (
 
 func getLoggingBillingAccountBucketConfigRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_logging_billing_account_bucket_config",
-		RFunc: NewLoggingBillingAccountBucketConfig,
+		Name:      "google_logging_billing_account_bucket_config",
+		CoreRFunc: NewLoggingBillingAccountBucketConfig,
 	}
 }
 
-func NewLoggingBillingAccountBucketConfig(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewLoggingBillingAccountBucketConfig(d *schema.ResourceData) schema.CoreResource {
 	r := &google.Logging{
 		Address: d.Address,
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
