@@ -7,16 +7,15 @@ import (
 
 func getLoggingBillingAccountSinkRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_logging_billing_account_sink",
-		RFunc: NewLoggingBillingAccountSink,
+		Name:      "google_logging_billing_account_sink",
+		CoreRFunc: NewLoggingBillingAccountSink,
 	}
 }
 
-func NewLoggingBillingAccountSink(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewLoggingBillingAccountSink(d *schema.ResourceData) schema.CoreResource {
 	r := &google.Logging{
 		Address: d.Address,
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
