@@ -7,16 +7,15 @@ import (
 
 func getLoggingOrganizationSinkRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_logging_organization_sink",
-		RFunc: NewLoggingOrganizationSink,
+		Name:      "google_logging_organization_sink",
+		CoreRFunc: NewLoggingOrganizationSink,
 	}
 }
 
-func NewLoggingOrganizationSink(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewLoggingOrganizationSink(d *schema.ResourceData) schema.CoreResource {
 	r := &google.Logging{
 		Address: d.Address,
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
