@@ -8,12 +8,15 @@ import (
 	"flag"
 	"fmt"
 	"math/big"
+	"net/url"
 	"os"
 	"path/filepath"
 	"regexp"
 	"sort"
 	"strings"
 
+	"github.com/infracost/infracost/internal/schema"
+
 	jsoniter "github.com/json-iterator/go"
 	"github.com/rs/zerolog"
 	"github.com/zclconf/go-cty/cty"
@@ -26,10 +29,13 @@ import (
 	"github.com/infracost/infracost/internal/hcl"
 	"github.com/infracost/infracost/internal/hcl/modules"
 	"github.com/infracost/infracost/internal/logging"
-	"github.com/infracost/infracost/internal/schema"
 )
 
-var json = jsoniter.ConfigCompatibleWithStandardLibrary
+var (
+	json = jsoniter.ConfigCompatibleWithStandardLibrary
+
+	moduleCacheRegex = regexp.MustCompile(`(?:.+)?\.infracost/terraform_modules/[^/]+/(.+)`)
+)
 
 type HCLProvider struct {
 	policyClient   *apiclient.PolicyAPIClient
@@ -96,7 +102,7 @@ func NewHCLProvider(ctx *config.ProjectContext, rootPath hcl.RootPath, config *H
 		return nil, fmt.Errorf("could not parse vars from plan flags %w", err)
 	}
 
-	options := []hcl.Option{hcl.OptionWithTFEnvVars(ctx.ProjectConfig.Env)}
+	options := []hcl.Option{hcl.OptionWithTFEnvVars(ctx.ProjectConfig.Env), hcl.OptionWithSpaceliftRemoteVarLoader(ctx)}
 
 	if len(v.vars) > 0 {
 		withPlanFlagVars := hcl.OptionWithPlanFlagVars(v.vars)
@@ -122,7 +128,7 @@ func NewHCLProvider(ctx *config.ProjectContext, rootPath hcl.RootPath, config *H
 	})
 	localWorkspace := ctx.ProjectConfig.TerraformWorkspace
 	if err == nil {
-		var loaderOpts []hcl.RemoteVariablesLoaderOption
+		var loaderOpts []hcl.TFCRemoteVariablesLoaderOption
 		if ctx.ProjectConfig.TerraformCloudWorkspace != "" && ctx.ProjectConfig.TerraformCloudOrg != "" {
 			loaderOpts = append(loaderOpts, hcl.RemoteVariablesLoaderWithRemoteConfig(hcl.TFCRemoteConfig{
 				Organization: ctx.ProjectConfig.TerraformCloudOrg,
@@ -131,7 +137,7 @@ func NewHCLProvider(ctx *config.ProjectContext, rootPath hcl.RootPath, config *H
 			}))
 		}
 
-		options = append(options, hcl.OptionWithRemoteVarLoader(
+		options = append(options, hcl.OptionWithTFCRemoteVarLoader(
 			credsSource.BaseCredentialSet.Host,
 			credsSource.BaseCredentialSet.Token,
 			localWorkspace,
@@ -239,6 +245,7 @@ func (p *HCLProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 // representation of the terraform plan JSON files from these Blocks, this is passed to the PlanJSONProvider.
 // The PlanJSONProvider uses this shallow representation to actually load Infracost resources.
 func (p *HCLProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, error) {
+
 	j := p.LoadPlanJSON()
 	if j.Error != nil {
 		return []*schema.Project{p.newProject(j)}, nil
@@ -442,7 +449,7 @@ func (p *HCLProvider) marshalModule(module *hcl.Module) ModuleOut {
 	configResources := map[string]struct{}{}
 	for _, block := range module.Blocks {
 		if block.Type() == "resource" {
-			out := p.getResourceOutput(block)
+			out := p.getResourceOutput(block, module.SourceURL)
 
 			if _, ok := configResources[out.Configuration.Address]; !ok {
 				moduleConfig.Resources = append(moduleConfig.Resources, out.Configuration)
@@ -481,23 +488,38 @@ func (p *HCLProvider) marshalModule(module *hcl.Module) ModuleOut {
 	}
 }
 
-func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
+func (p *HCLProvider) getResourceOutput(block *hcl.Block, moduleSourceURL string) ResourceOutput {
 	jsonValues := marshalAttributeValues(block.Type(), block.Values())
 	p.marshalBlock(block, jsonValues)
+	calls := block.CallDetails()
+	metadata := map[string]interface{}{
+		"filename":  block.Filename,
+		"startLine": block.StartLine,
+		"endLine":   block.EndLine,
+		"calls":     calls,
+		"checksum":  generateChecksum(jsonValues),
+	}
+	if attrsWithMissingKeys := block.AttributesWithUnknownKeys(); len(attrsWithMissingKeys) > 0 {
+		metadata["attributesWithUnknownKeys"] = attrsWithMissingKeys
+	}
+
+	// if there is a non-empty module source url, this means that resource comes from a remote module
+	// in this case we should add the module source url to the metadata.
+	if moduleSourceURL != "" && moduleCacheRegex.MatchString(block.Filename) {
+		filename := buildModuleFilename(block.Filename, moduleSourceURL)
+		if filename != "" {
+			metadata["moduleFilename"] = filename
+		}
+	}
+
 	planned := ResourceJSON{
-		Address:       block.FullName(),
-		Mode:          "managed",
-		Type:          block.TypeLabel(),
-		Name:          stripCountOrForEach(block.NameLabel()),
-		Index:         block.Index(),
-		SchemaVersion: 0,
-		InfracostMetadata: map[string]interface{}{
-			"filename":  block.Filename,
-			"startLine": block.StartLine,
-			"endLine":   block.EndLine,
-			"calls":     block.CallDetails(),
-			"checksum":  generateChecksum(jsonValues),
-		},
+		Address:           block.FullName(),
+		Mode:              "managed",
+		Type:              block.TypeLabel(),
+		Name:              stripCountOrForEach(block.NameLabel()),
+		Index:             block.Index(),
+		SchemaVersion:     0,
+		InfracostMetadata: metadata,
 	}
 
 	changes := ResourceChangesJSON{
@@ -533,16 +555,91 @@ func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
 	}
 }
 
+func buildModuleFilename(filename string, moduleSourceURL string) string {
+	httpsURL, err := transformSSHToHTTPS(moduleSourceURL)
+	if err != nil {
+		logging.Logger.Debug().Err(err).Msgf("failed to build module filename, could not transform url %s to https", moduleSourceURL)
+		return ""
+	}
+
+	u, err := url.Parse(httpsURL)
+	if err != nil {
+		logging.Logger.Debug().Err(err).Msgf("failed to build module filename,could not parse url %s", httpsURL)
+		return ""
+	}
+
+	ref := "HEAD"
+	queryRef := u.Query().Get("ref")
+	if queryRef != "" {
+		ref = queryRef
+	}
+	u.Path += "/blob/" + ref + "/"
+	u.RawQuery = ""
+
+	matches := moduleCacheRegex.FindStringSubmatch(filename)
+	moduleFilename := u.String() + matches[1]
+	return moduleFilename
+}
+
+func transformSSHToHTTPS(sshURL string) (string, error) {
+	if !strings.HasPrefix(sshURL, "git@") {
+		// nothing to do, the URL is not an SSH URL
+		return sshURL, nil
+	}
+
+	colonCount := strings.Count(sshURL, ":")
+	var domainAndPort, path string
+
+	switch colonCount {
+	case 1:
+		components := strings.SplitN(sshURL, ":", 2)
+		userAndDomain := strings.Split(components[0], "@")
+		if len(userAndDomain) != 2 {
+			return "", fmt.Errorf("invalid SSH URL format")
+		}
+		domainAndPort = userAndDomain[1]
+		path = components[1]
+	case 2:
+		// case with a port in the url
+		components := strings.SplitN(sshURL, ":", 3)
+		userAndDomain := strings.Split(components[0], "@")
+		if len(userAndDomain) != 2 {
+			return "", fmt.Errorf("invalid SSH URL format")
+		}
+		domainAndPort = userAndDomain[1]
+		path = components[2]
+	default:
+		return "", fmt.Errorf("invalid SSH URL format")
+	}
+
+	// remove port if it exists
+	domainComponents := strings.SplitN(domainAndPort, ":", 2)
+	domain := domainComponents[0]
+
+	return strings.TrimSuffix(fmt.Sprintf("https://%s/%s", domain, path), "/"), nil
+}
+
 func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
 	providerConfigKey := block.Values().GetAttr("config_key").AsString()
 
-	name := block.TypeLabel()
+	providerType := block.TypeLabel()
+	name := providerType
 	if a := block.GetAttribute("alias"); a != nil {
 		name = name + "." + a.AsString()
 	}
 
 	region := block.GetAttribute("region").AsString()
 
+	metadata := map[string]interface{}{
+		"filename":   block.Filename,
+		"start_line": block.StartLine,
+		"end_line":   block.EndLine,
+	}
+
+	if attrsWithMissingKeys := block.AttributesWithUnknownKeys(); len(attrsWithMissingKeys) > 0 {
+		metadata["attributes_with_unknown_keys"] = attrsWithMissingKeys
+	}
+
 	p.schema.Configuration.ProviderConfig[providerConfigKey] = ProviderConfig{
 		Name: name,
 		Expressions: map[string]interface{}{
@@ -550,22 +647,24 @@ func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
 				"constant_value": region,
 			},
 		},
-		InfracostMetadata: map[string]interface{}{
-			"filename":   block.Filename,
-			"start_line": block.StartLine,
-			"end_line":   block.EndLine,
-		},
+		InfracostMetadata: metadata,
 	}
 
-	defaultTags := p.marshalDefaultTagsBlock(block)
-	if defaultTags != nil {
-		p.schema.Configuration.ProviderConfig[providerConfigKey].Expressions["default_tags"] = []map[string]interface{}{defaultTags}
+	switch providerType {
+	case "aws":
+		if defaultTags := p.marshalAWSDefaultTagsBlock(block); defaultTags != nil {
+			p.schema.Configuration.ProviderConfig[providerConfigKey].Expressions["default_tags"] = []map[string]interface{}{defaultTags}
+		}
+	case "google":
+		if defaultLabels := p.marshalGoogleDefaultTagsBlock(block); defaultLabels != nil {
+			p.schema.Configuration.ProviderConfig[providerConfigKey].Expressions["default_labels"] = defaultLabels
+		}
 	}
 
 	return name
 }
 
-func (p *HCLProvider) marshalDefaultTagsBlock(providerBlock *hcl.Block) map[string]interface{} {
+func (p *HCLProvider) marshalAWSDefaultTagsBlock(providerBlock *hcl.Block) map[string]interface{} {
 	b := providerBlock.GetChildBlock("default_tags")
 	if b == nil {
 		return nil
@@ -623,11 +722,79 @@ func (p *HCLProvider) marshalDefaultTagsBlock(providerBlock *hcl.Block) map[stri
 		marshalledTags[tag] = tagValue
 	}
 
-	return map[string]interface{}{
-		"tags": map[string]interface{}{
-			"constant_value": marshalledTags,
-		},
+	tagsVal := map[string]interface{}{
+		"constant_value": marshalledTags,
 	}
+
+	if refs := tags.ReferencesCausingUnknownKeys(); len(refs) > 0 {
+		tagsVal["missing_attributes_causing_unknown_keys"] = refs
+	}
+
+	return map[string]interface{}{
+		"tags": tagsVal,
+	}
+}
+
+func (p *HCLProvider) marshalGoogleDefaultTagsBlock(providerBlock *hcl.Block) map[string]interface{} {
+	tags := providerBlock.GetAttribute("default_labels")
+	if tags == nil {
+		return nil
+	}
+
+	marshalledTags := make(map[string]interface{})
+
+	value := tags.Value()
+	if value.IsNull() || !value.IsKnown() || !value.CanIterateElements() {
+		return nil
+	}
+
+	for tag, val := range value.AsValueMap() {
+		if !val.IsKnown() {
+			p.logger.Debug().Msgf("tag %s has unknown value, cannot marshal", tag)
+			continue
+		}
+
+		if val.Type().Equals(cty.Bool) {
+			var tagValue bool
+			err := gocty.FromCtyValue(val, &tagValue)
+			if err != nil {
+				p.logger.Debug().Err(err).Msgf("could not marshal tag %s to bool value", tag)
+				continue
+			}
+
+			marshalledTags[tag] = fmt.Sprintf("%t", tagValue)
+			continue
+		}
+
+		if val.Type() == cty.Number {
+			var tagValue big.Float
+			err := gocty.FromCtyValue(val, &tagValue)
+			if err != nil {
+				p.logger.Debug().Err(err).Msgf("could not marshal tag %s to number value", tag)
+				continue
+			}
+
+			marshalledTags[tag] = tagValue.String()
+			continue
+		}
+
+		var tagValue string
+		err := gocty.FromCtyValue(val, &tagValue)
+		if err != nil {
+			p.logger.Debug().Err(err).Msgf("could not marshal tag %s to string value", tag)
+			continue
+		}
+
+		marshalledTags[tag] = tagValue
+	}
+
+	tagsVal := map[string]interface{}{
+		"constant_value": marshalledTags,
+	}
+	if refs := tags.ReferencesCausingUnknownKeys(); len(refs) > 0 {
+		tagsVal["missing_attributes_causing_unknown_keys"] = refs
+	}
+	return tagsVal
 }
 
 func (p *HCLProvider) countReferences(block *hcl.Block) *countExpression {
