@@ -2,9 +2,13 @@ package terraform
 
 import (
 	"bytes"
+	json2 "encoding/json"
+	"flag"
 	"fmt"
 	"io"
+	"os"
 	"path"
+	"reflect"
 	"strings"
 	"testing"
 	"text/template"
@@ -18,11 +22,14 @@ import (
 	"github.com/zclconf/go-cty/cty"
 
 	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/credentials"
 	"github.com/infracost/infracost/internal/hcl"
 	"github.com/infracost/infracost/internal/hcl/modules"
 	"github.com/infracost/infracost/internal/sync"
 )
 
+var update = flag.Bool("update", false, "update .golden files")
+
 func setMockAttributes(blockAtts map[string]map[string]string) hcl.SetAttributesFunc {
 	count := map[string]int{}
 
@@ -68,6 +75,7 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 	tests := []struct {
 		name     string
 		attrs    map[string]map[string]string
+		chdir    bool
 		warnings []int
 	}{
 		{
@@ -172,6 +180,13 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 		{
 			name: "builds module configuration correctly with count",
 		},
+		{
+			name: "adds_source_url_from_remote_module",
+		},
+		{
+			name:  "adds_source_url_from_remote_module_chdir",
+			chdir: true,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -183,7 +198,16 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 			ctx := config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, logrus.Fields{})
 			moduleParser := modules.NewSharedHCLParser()
 			pl := hcl.NewProjectLocator(logger, nil)
-			mods := pl.FindRootModules(testPath)
+			startingPath := testPath
+			initialPath, err := os.Getwd()
+			require.NoError(t, err)
+			if tt.chdir {
+				err := os.Chdir(testPath)
+				require.NoError(t, err)
+				startingPath = "."
+			}
+
+			mods := pl.FindRootModules(startingPath)
 			options := []hcl.Option{hcl.OptionWithBlockBuilder(
 				hcl.BlockBuilder{
 					MockFunc: func(a *hcl.Attribute) cty.Value {
@@ -202,7 +226,7 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 			parser := hcl.NewParser(
 				mods[0],
 				hcl.CreateEnvFileMatcher([]string{}, nil),
-				modules.NewModuleLoader(testPath, moduleParser, nil, config.TerraformSourceMap{}, logger, &sync.KeyMutex{}),
+				modules.NewModuleLoader(startingPath, moduleParser, &modules.CredentialsSource{FetchToken: credentials.FindTerraformCloudToken}, config.TerraformSourceMap{}, logger, &sync.KeyMutex{}),
 				logger,
 				options...,
 			)
@@ -215,6 +239,10 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 			root := p.LoadPlanJSON()
 
 			require.NoError(t, root.Error)
+			if tt.chdir {
+				err = os.Chdir(initialPath)
+				require.NoError(t, err)
+			}
 
 			// uncomment and run `make test` to update the expectations
 			// var prettyJSON bytes.Buffer
@@ -232,7 +260,19 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 
 			expected := exp.String()
 			actual := string(root.JSON)
-			assert.JSONEq(t, expected, actual)
+			if !assert.JSONEq(t, expected, actual) {
+				var prettyJSON bytes.Buffer
+				err = json2.Indent(&prettyJSON, root.JSON, "", "  ")
+				assert.NoError(t, err)
+
+				if update != nil && *update {
+					err = os.WriteFile(path.Join(testPath, "expected.json"), append(prettyJSON.Bytes(), "\n"...), 0600)
+					assert.NoError(t, err)
+				} else {
+					err = os.WriteFile(path.Join(testPath, "actual.json"), append(prettyJSON.Bytes(), "\n"...), 0600)
+					assert.NoError(t, err)
+				}
+			}
 
 			codes := make([]int, len(root.Module.Warnings))
 			for i, w := range root.Module.Warnings {
@@ -244,3 +284,31 @@ func TestHCLProvider_LoadPlanJSON(t *testing.T) {
 		})
 	}
 }
+
+func TestTransformSSHToHTTPS(t *testing.T) {
+	tests := []struct {
+		input    string
+		expected string
+	}{
+		{"git@github.com:user/repo.git", "https://github.com/user/repo.git"},
+		{"git@gitlab.com:group/project.git", "https://gitlab.com/group/project.git"},
+		{"git@bitbucket.org:team/repo.git", "https://bitbucket.org/team/repo.git"},
+		{"git@myserver.com:2222:user/repo.git", "https://myserver.com/user/repo.git"},                                    // with port
+		{"git@ssh.dev.azure.com:v3/organization/project/repo", "https://ssh.dev.azure.com/v3/organization/project/repo"}, // Azure Repos
+		{"invalid-url", "invalid-url"},                                     // invalid SSH URL
+		{"user@github.com:user/repo.git", "user@github.com:user/repo.git"}, // unexpected username
+	}
+
+	for _, test := range tests {
+		output, err := transformSSHToHTTPS(test.input)
+		if err != nil {
+			if test.expected != "" {
+				t.Errorf("transformSSHToHTTPS(%q) returned an error: %v", test.input, err)
+			}
+		} else {
+			if !reflect.DeepEqual(output, test.expected) {
+				t.Errorf("transformSSHToHTTPS(%q) = %q, want %q", test.input, output, test.expected)
+			}
+		}
+	}
+}
