@@ -4,11 +4,16 @@ import (
 	"bytes"
 	stdJson "encoding/json"
 	"fmt"
+	"os"
+	"path/filepath"
 	"regexp"
 	"sort"
 	"strconv"
 	"strings"
 
+	"github.com/hashicorp/go-version"
+	"gopkg.in/yaml.v3"
+
 	"github.com/google/go-cmp/cmp"
 	"github.com/pkg/errors"
 	"github.com/tidwall/gjson"
@@ -322,6 +327,21 @@ func parseProviderConfig(providerConf gjson.Result) []schema.ProviderMetadata {
 			EndLine:   conf.Get("infracost_metadata.end_line").Int(),
 		}
 
+		unknownKeys := conf.Get("infracost_metadata.attributes_with_unknown_keys").Array()
+		for _, unknownKey := range unknownKeys {
+			vars := unknownKey.Get("missing_variables")
+			if vars.IsArray() {
+				vals := make([]string, 0, len(vars.Array()))
+				for _, v := range vars.Array() {
+					vals = append(vals, v.String())
+				}
+				md.AttributesWithUnknownKeys = append(md.AttributesWithUnknownKeys, schema.AttributeWithUnknownKeys{
+					Attribute:        unknownKey.Get("attribute").String(),
+					MissingVariables: vals,
+				})
+			}
+		}
+
 		for _, defaultTags := range conf.Get("expressions.default_tags").Array() {
 			if md.DefaultTags == nil {
 				md.DefaultTags = make(map[string]string)
@@ -481,22 +501,50 @@ func getSpecialContext(d *schema.ResourceData) map[string]interface{} {
 	}
 }
 
-func parseDefaultTags(providerConf, resConf gjson.Result) *map[string]string {
+func parseAWSDefaultTags(providerConf, resConf gjson.Result) (map[string]string, []string) {
 	// this only works for aws, we'll need to review when other providers support default tags
 	providerKey := parseProviderKey(resConf)
 	dTagsArray := providerConf.Get(fmt.Sprintf("%s.expressions.default_tags", gjsonEscape(providerKey))).Array()
 	if len(dTagsArray) == 0 {
-		return nil
+		return nil, nil
 	}
 
 	defaultTags := make(map[string]string)
+	var missingAttrsCausingUnknownKeys []string
 	for _, dTags := range dTagsArray {
 		for k, v := range dTags.Get("tags.constant_value").Map() {
 			defaultTags[k] = v.String()
 		}
+		for _, address := range dTags.Get("tags.missing_attributes_causing_unknown_keys").Array() {
+			if address.String() == "" {
+				continue
+			}
+			missingAttrsCausingUnknownKeys = append(missingAttrsCausingUnknownKeys, address.String())
+		}
+	}
+	return defaultTags, missingAttrsCausingUnknownKeys
+}
+
+func parseGoogleDefaultTags(providerConf, resConf gjson.Result) (map[string]string, []string) {
+	providerKey := parseProviderKey(resConf)
+	defaultTags := make(map[string]string)
+	for k, v := range providerConf.Get(fmt.Sprintf("%s.expressions.default_labels.constant_value", gjsonEscape(providerKey))).Map() {
+		defaultTags[k] = v.String()
+	}
+	var missingAttrsCausingUnknownKeys []string
+	for _, address := range providerConf.Get(
+		fmt.Sprintf(
+			"%s.expressions.default_labels.missing_attributes_causing_unknown_keys",
+			gjsonEscape(providerKey),
+		),
+	).Array() {
+		if address.String() == "" {
+			continue
+		}
+		missingAttrsCausingUnknownKeys = append(missingAttrsCausingUnknownKeys, address.String())
 	}
 
-	return &defaultTags
+	return defaultTags, missingAttrsCausingUnknownKeys
 }
 
 func overrideRegion(d *schema.ResourceData, config *config.Config) string {
@@ -780,28 +828,174 @@ func (p *Parser) parseConfReferences(resData map[string]*schema.ResourceData, co
 	return found
 }
 
+type YorConfig struct {
+	Name  string `yaml:"name"`
+	Value struct {
+		Default string `yaml:"default"`
+	} `yaml:"value"`
+	TagGroups []struct {
+		Name string `yaml:"name"`
+		Tags []struct {
+			Name  string `yaml:"name"`
+			Value struct {
+				Default string `yaml:"default"`
+			} `yaml:"value"`
+		} `yaml:"tags"`
+	} `yaml:"tag_groups"`
+}
+
+func (p *Parser) parseYorTagsFromConfigFile(path string, tags map[string]string) {
+
+	data, err := os.ReadFile(path)
+	if err != nil {
+		logging.Logger.Debug().Msgf("failed to read yor config: %s", err)
+		return
+	}
+
+	var conf YorConfig
+	if err := yaml.Unmarshal(data, &conf); err != nil {
+		logging.Logger.Debug().Msgf("failed to unmarshal yor config: %s", err)
+		return
+	}
+
+	// single tag style config
+	if conf.Name != "" && conf.Value.Default != "" {
+		tags[conf.Name] = conf.Value.Default
+	}
+
+	// tag group style config
+	for _, tg := range conf.TagGroups {
+		for _, t := range tg.Tags {
+			if t.Name == "" || t.Value.Default == "" {
+				continue
+			}
+			tags[t.Name] = t.Value.Default
+		}
+	}
+}
+
+func (p *Parser) parseYorTagsFromJSON(rawJSON string, tags map[string]string) {
+	var simpleTags map[string]string
+	if err := stdJson.Unmarshal([]byte(rawJSON), &simpleTags); err == nil {
+		for k, v := range simpleTags {
+			if k == "" || v == "" {
+				continue
+			}
+			tags[k] = v
+		}
+	} else {
+		logging.Logger.Debug().Msgf("failed to unmarshal yor simple tags json: %s", err)
+	}
+}
+
 func (p *Parser) parseTags(data map[string]*schema.ResourceData, confLoader *ConfLoader, providerConf gjson.Result) {
+	awsTagParsingConfig := aws.TagParsingConfig{PropagateDefaultsToVolumeTags: hcl.ConstraintsAllowVersionOrAbove(p.providerConstraints.AWS, hcl.AWSVersionConstraintVolumeTags)}
+
+	externalTags := make(map[string]string)
+	if path := p.ctx.ProjectConfig.YorConfigPath; path != "" {
+		if root := p.ctx.RunContext.Config.RootPath; root != "" && !filepath.IsAbs(path) {
+			path = filepath.Join(root, path)
+		}
+		p.parseYorTagsFromConfigFile(path, externalTags)
+	}
+	if yorSimpleTags := os.Getenv("YOR_SIMPLE_TAGS"); yorSimpleTags != "" {
+		p.parseYorTagsFromJSON(yorSimpleTags, externalTags)
+	}
+
 	for _, resourceData := range data {
+
+		var missingVarsCausingUnknownTagKeys []string
+		var missingVarsCausingUnknownDefaultTagKeys []string
 		providerPrefix := getProviderPrefix(resourceData.Type)
-		var tags *map[string]string
+		defaultTagSupport := p.areDefaultTagsSupported(providerPrefix)
+		var tags map[string]string
+		var defaultTags map[string]string
+		resConf := confLoader.GetResourceConfJSON(resourceData.Address)
 		switch providerPrefix {
 		case "aws":
-			resConf := confLoader.GetResourceConfJSON(resourceData.Address)
-			defaultTags := parseDefaultTags(providerConf, resConf)
-
-			tags = aws.ParseTags(defaultTags, resourceData, aws.TagParsingConfig{PropagateDefaultsToVolumeTags: p.providerConstraints.AWS.Check(hcl.AWSVersionConstraintVolumeTags)})
+			if defaultTagSupport {
+				defaultTags, missingVarsCausingUnknownDefaultTagKeys = parseAWSDefaultTags(providerConf, resConf)
+			}
+			tags, missingVarsCausingUnknownTagKeys = aws.ParseTags(externalTags, defaultTags, resourceData, awsTagParsingConfig)
 		case "azurerm":
-			tags = azure.ParseTags(resourceData)
+			tags, missingVarsCausingUnknownTagKeys = azure.ParseTags(externalTags, resourceData)
 		case "google":
-			tags = google.ParseTags(resourceData)
+			if defaultTagSupport {
+				defaultTags, missingVarsCausingUnknownDefaultTagKeys = parseGoogleDefaultTags(providerConf, resConf)
+			}
+			tags, missingVarsCausingUnknownTagKeys = google.ParseTags(resourceData, externalTags, defaultTags)
 		default:
 			logging.Logger.Debug().Msgf("Unsupported provider %s", providerPrefix)
 		}
 
-		resourceData.Tags = tags
+		if conf := providerConf.Get(gjsonEscape(parseProviderKey(resConf))); conf.Exists() {
+			if metadata := conf.Get("infracost_metadata"); metadata.Exists() {
+				providerLink := metadata.Get("filename").String()
+				if providerLine := metadata.Get("start_line").Int(); providerLine > 0 {
+					providerLink = fmt.Sprintf("%s:%d", providerLink, providerLine)
+				}
+				resourceData.ProviderLink = providerLink
+			}
+		}
+
+		if tags != nil {
+			resourceData.Tags = &tags
+		}
+		if defaultTags != nil {
+			resourceData.DefaultTags = &defaultTags
+		}
+		resourceData.ProviderSupportsDefaultTags = defaultTagSupport
+		resourceData.TagPropagation = p.getTagPropagationInfo(resourceData)
+		resourceData.MissingVarsCausingUnknownTagKeys = missingVarsCausingUnknownTagKeys
+		resourceData.MissingVarsCausingUnknownDefaultTagKeys = missingVarsCausingUnknownDefaultTagKeys
 	}
 }
 
+var (
+	versionAWSProviderForDefaultTagSupport = version.Must(version.NewVersion("3.38.0"))
+	versionGoogleProviderForDefaultTags    = version.Must(version.NewVersion("5.0.0"))
+)
+
+func (p *Parser) areDefaultTagsSupported(providerPrefix string) bool {
+	switch providerPrefix {
+	case "aws":
+		// default tags were added in aws provider v3.38.0 - if the constraints allow a version before this,
+		// we can't rely on default tag support
+		return hcl.ConstraintsAllowVersionOrAbove(p.providerConstraints.AWS, versionAWSProviderForDefaultTagSupport)
+	case "google":
+		// default tags (labels) were added in google provider v5.0.0 - if the constraints allow a version before this,
+		// we can't rely on default tag support
+		return hcl.ConstraintsAllowVersionOrAbove(p.providerConstraints.Google, versionGoogleProviderForDefaultTags)
+	default:
+		return false
+	}
+}
+
+func (p *Parser) getTagPropagationInfo(resource *schema.ResourceData) *schema.TagPropagation {
+	if expected, ok := aws.ExpectedPropagations[resource.Type]; ok {
+		propagateTags := resource.GetStringOrDefault(expected.Attribute, "")
+		propagation := &schema.TagPropagation{
+			From:      &propagateTags,
+			To:        expected.To,
+			Attribute: expected.Attribute,
+		}
+		hasRequired := true
+		for _, required := range expected.Requires {
+			hasRequired = hasRequired && resource.Get(required).Exists()
+		}
+		propagation.HasRequiredAttributes = hasRequired
+		if expected.RefMap != nil {
+			if attr, ok := expected.RefMap[propagateTags]; ok {
+				if ref, ok := resource.ReferencesMap[attr]; ok && len(ref) == 1 {
+					propagation.Tags = ref[0].Tags
+				}
+			}
+		}
+		return propagation
+	}
+	return nil
+}
+
 func isInfracostResource(res *schema.ResourceData) bool {
 	for _, p := range infracostProviderNames {
 		if res.ProviderName == p {
