@@ -10,7 +10,6 @@ import (
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/schema"
-	"github.com/infracost/infracost/internal/ui"
 )
 
 type PlanJSONProvider struct {
@@ -40,6 +39,18 @@ func NewPlanJSONProvider(ctx *config.ProjectContext, includePastResources bool)
 	}
 }
 
+func (p *PlanJSONProvider) ProjectName() string {
+	return config.CleanProjectName(p.ctx.ProjectConfig.Path)
+}
+
+func (p *PlanJSONProvider) VarFiles() []string {
+	return nil
+}
+
+func (p *PlanJSONProvider) RelativePath() string {
+	return p.ctx.ProjectConfig.Path
+}
+
 func (p *PlanJSONProvider) Context() *config.ProjectContext {
 	return p.ctx
 }
@@ -61,19 +72,12 @@ func (p *PlanJSONProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 }
 
 func (p *PlanJSONProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, error) {
-	spinner := ui.NewSpinner("Extracting only cost-related params from terraform", ui.SpinnerOptions{
-		EnableLogging: p.ctx.RunContext.Config.IsLogging(),
-		NoColor:       p.ctx.RunContext.Config.NoColor,
-		Indent:        "  ",
-	})
-	defer spinner.Fail()
-
 	j, err := os.ReadFile(p.Path)
 	if err != nil {
 		return []*schema.Project{}, fmt.Errorf("Error reading Terraform plan JSON file %w", err)
 	}
 
-	project, err := p.LoadResourcesFromSrc(usage, j, spinner)
+	project, err := p.LoadResourcesFromSrc(usage, j)
 	if err != nil {
 		return nil, err
 	}
@@ -81,7 +85,7 @@ func (p *PlanJSONProvider) LoadResources(usage schema.UsageMap) ([]*schema.Proje
 	return []*schema.Project{project}, nil
 }
 
-func (p *PlanJSONProvider) LoadResourcesFromSrc(usage schema.UsageMap, j []byte, spinner *ui.Spinner) (*schema.Project, error) {
+func (p *PlanJSONProvider) LoadResourcesFromSrc(usage schema.UsageMap, j []byte) (*schema.Project, error) {
 	metadata := schema.DetectProjectMetadata(p.ctx.ProjectConfig.Path)
 	metadata.Type = p.Type()
 	p.AddMetadata(metadata)
@@ -112,9 +116,5 @@ func (p *PlanJSONProvider) LoadResourcesFromSrc(usage schema.UsageMap, j []byte,
 		}
 	}
 
-	if spinner != nil {
-		spinner.Success()
-	}
-
 	return project, nil
 }
