@@ -4,11 +4,10 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 
-	"github.com/rs/zerolog/log"
-
 	"github.com/shopspring/decimal"
 )
 
@@ -58,7 +57,7 @@ func (r *LightsailInstance) BuildResource() *schema.Resource {
 
 	specs, ok := bundlePrefixMappings[bundlePrefix]
 	if !ok {
-		log.Warn().Msgf("Skipping resource %s. Unrecognized bundle_id %s", r.Address, r.BundleID)
+		logging.Logger.Warn().Msgf("Skipping resource %s. Unrecognized bundle_id %s", r.Address, r.BundleID)
 		return nil
 	}
 
