@@ -3,9 +3,10 @@ package aws
 import (
 	"fmt"
 
+	"github.com/shopspring/decimal"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
-	"github.com/shopspring/decimal"
 )
 
 type MWAAEnvironment struct {
@@ -21,10 +22,16 @@ type MWAAEnvironment struct {
 }
 
 // If the resource requires a usage parameter
-var MWAAEnvironmentUsageSchema = []*schema.UsageItem{
-	{Key: "additional_workers", DefaultValue: 0.0, ValueType: schema.Float64},
-	{Key: "additional_schedulers", DefaultValue: 0.0, ValueType: schema.Float64},
-	{Key: "meta_database_gb", DefaultValue: 0.0, ValueType: schema.Float64},
+func (a *MWAAEnvironment) CoreType() string {
+	return "MWAAEnvironment"
+}
+
+func (a *MWAAEnvironment) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "additional_workers", DefaultValue: 0.0, ValueType: schema.Float64},
+		{Key: "additional_schedulers", DefaultValue: 0.0, ValueType: schema.Float64},
+		{Key: "meta_database_gb", DefaultValue: 0.0, ValueType: schema.Float64},
+	}
 }
 
 // If the resource requires a usage parameter
@@ -53,7 +60,7 @@ func (a *MWAAEnvironment) BuildResource() *schema.Resource {
 
 	return &schema.Resource{
 		Name:           a.Address,
-		UsageSchema:    MWAAEnvironmentUsageSchema,
+		UsageSchema:    a.UsageSchema(),
 		CostComponents: costComponents,
 	}
 }
@@ -98,5 +105,6 @@ func (a *MWAAEnvironment) newStorageCostComponent(quantity *decimal.Decimal) *sc
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
