@@ -4,9 +4,10 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/shopspring/decimal"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
-	"github.com/shopspring/decimal"
 )
 
 type NeptuneClusterInstance struct {
@@ -18,8 +19,14 @@ type NeptuneClusterInstance struct {
 	MonthlyCPUCreditHrs *int64 `infracost_usage:"monthly_cpu_credit_hrs"`
 }
 
-var NeptuneClusterInstanceUsageSchema = []*schema.UsageItem{
-	{Key: "monthly_cpu_credit_hrs", ValueType: schema.Int64, DefaultValue: 0},
+func (r *NeptuneClusterInstance) CoreType() string {
+	return "NeptuneClusterInstance"
+}
+
+func (r *NeptuneClusterInstance) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "monthly_cpu_credit_hrs", ValueType: schema.Int64, DefaultValue: 0},
+	}
 }
 
 func (r *NeptuneClusterInstance) PopulateUsage(u *schema.UsageData) {
@@ -48,7 +55,7 @@ func (r *NeptuneClusterInstance) BuildResource() *schema.Resource {
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
-		UsageSchema:    NeptuneClusterInstanceUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
 
@@ -96,5 +103,6 @@ func (r *NeptuneClusterInstance) cpuCreditsCostComponent(quantity *decimal.Decim
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
