@@ -1,9 +1,6 @@
 package aws
 
 import (
-	"golang.org/x/text/cases"
-	"golang.org/x/text/language"
-
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 
@@ -17,6 +14,7 @@ type RDSCluster struct {
 	Region                    string
 	EngineMode                string
 	Engine                    string
+	IOOptimized               bool
 	BackupRetentionPeriod     int64
 	WriteRequestsPerSec       *int64   `infracost_usage:"write_requests_per_sec"`
 	ReadRequestsPerSec        *int64   `infracost_usage:"read_requests_per_sec"`
@@ -25,7 +23,7 @@ type RDSCluster struct {
 	AverageStatementsPerHr    *int64   `infracost_usage:"average_statements_per_hr"`
 	BacktrackWindowHrs        *int64   `infracost_usage:"backtrack_window_hrs"`
 	SnapshotExportSizeGB      *float64 `infracost_usage:"snapshot_export_size_gb"`
-	CapacityUnitsPerHr        *int64   `infracost_usage:"capacity_units_per_hr"`
+	CapacityUnitsPerHr        *float64 `infracost_usage:"capacity_units_per_hr"`
 	BackupSnapshotSizeGB      *float64 `infracost_usage:"backup_snapshot_size_gb"`
 }
 
@@ -42,7 +40,7 @@ func (r *RDSCluster) UsageSchema() []*schema.UsageItem {
 		{Key: "average_statements_per_hr", ValueType: schema.Int64, DefaultValue: 0},
 		{Key: "backtrack_window_hrs", ValueType: schema.Int64, DefaultValue: 0},
 		{Key: "snapshot_export_size_gb", ValueType: schema.Float64, DefaultValue: 0},
-		{Key: "capacity_units_per_hr", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "capacity_units_per_hr", ValueType: schema.Float64, DefaultValue: 0},
 		{Key: "backup_snapshot_size_gb", ValueType: schema.Float64, DefaultValue: 0},
 	}
 }
@@ -54,7 +52,7 @@ func (r *RDSCluster) PopulateUsage(u *schema.UsageData) {
 func (r *RDSCluster) BuildResource() *schema.Resource {
 	costComponents := make([]*schema.CostComponent, 0)
 
-	databaseEngineMode := cases.Title(language.English).String(r.EngineMode)
+	databaseEngineMode := strings.ToLower(r.EngineMode)
 	if databaseEngineMode == "" {
 		databaseEngineMode = "provisioned"
 	}
@@ -65,6 +63,7 @@ func (r *RDSCluster) BuildResource() *schema.Resource {
 	switch r.Engine {
 	case "aurora", "aurora-mysql":
 		databaseEngine = "Aurora MySQL"
+		databaseEngineStorageType = "(Any|Aurora MySQL)"
 	case "aurora-postgresql":
 		databaseEngine = "Aurora PostgreSQL"
 		databaseEngineStorageType = databaseEngine
@@ -72,7 +71,7 @@ func (r *RDSCluster) BuildResource() *schema.Resource {
 
 	var auroraCapacityUnits *decimal.Decimal
 	if r.CapacityUnitsPerHr != nil {
-		auroraCapacityUnits = decimalPtr(decimal.NewFromInt(*r.CapacityUnitsPerHr))
+		auroraCapacityUnits = decimalPtr(decimal.NewFromFloat(*r.CapacityUnitsPerHr))
 	}
 
 	if strings.ToLower(databaseEngineMode) == "serverless" {
@@ -85,7 +84,7 @@ func (r *RDSCluster) BuildResource() *schema.Resource {
 				VendorName:    strPtr("aws"),
 				Region:        strPtr(r.Region),
 				Service:       strPtr("AmazonRDS"),
-				ProductFamily: strPtr(databaseEngineMode),
+				ProductFamily: strPtr("Serverless"),
 				AttributeFilters: []*schema.AttributeFilter{
 					{Key: "databaseEngine", ValueRegex: regexPtr(databaseEngine)},
 				},
@@ -106,7 +105,7 @@ func (r *RDSCluster) BuildResource() *schema.Resource {
 		costComponents = append(costComponents, r.auroraBackupStorageCostComponent(totalBackupStorageGB, databaseEngine))
 	}
 
-	if databaseEngineMode != "Serverless" && !strings.Contains(r.Engine, "postgresql") {
+	if databaseEngineMode != "serverless" && !strings.Contains(r.Engine, "postgresql") {
 		var totalBacktrackChangeRecords *decimal.Decimal
 
 		if r.AverageStatementsPerHr != nil && r.ChangeRecordsPerStatement != nil && r.BacktrackWindowHrs != nil {
@@ -116,6 +115,7 @@ func (r *RDSCluster) BuildResource() *schema.Resource {
 
 			totalBacktrackChangeRecords = decimalPtr(r.calculateBacktrack(averageStatements, backtrackChangeRecords, backtrackWindowHours))
 		}
+
 		costComponents = append(costComponents, r.auroraBacktrackCostComponent(totalBacktrackChangeRecords))
 	}
 
@@ -162,9 +162,16 @@ func (r *RDSCluster) auroraStorageCostComponents(databaseEngineStorageType strin
 		monthlyIORequests = decimalPtr(r.calculateIORequests(*readRequestsPerSecond, *writeRequestsPerSecond))
 	}
 
+	label := "Storage"
+	usageType := "Aurora:StorageUsage$"
+	if r.IOOptimized {
+		label = "Storage (I/O-optimized)"
+		usageType = "Aurora:IO-OptimizedStorageUsage$"
+	}
+
 	return []*schema.CostComponent{
 		{
-			Name:            "Storage",
+			Name:            label,
 			Unit:            "GB",
 			UnitMultiplier:  decimal.NewFromInt(1),
 			MonthlyQuantity: storageGB,
@@ -175,7 +182,7 @@ func (r *RDSCluster) auroraStorageCostComponents(databaseEngineStorageType strin
 				ProductFamily: strPtr("Database Storage"),
 				AttributeFilters: []*schema.AttributeFilter{
 					{Key: "databaseEngine", ValueRegex: regexPtr(databaseEngineStorageType)},
-					{Key: "usagetype", ValueRegex: regexPtr("Aurora:StorageUsage$")},
+					{Key: "usagetype", ValueRegex: regexPtr(usageType)},
 				},
 			},
 			UsageBased: true,
@@ -222,10 +229,11 @@ func (r *RDSCluster) auroraBackupStorageCostComponent(totalBackupStorageGB *deci
 
 func (r *RDSCluster) auroraBacktrackCostComponent(backtrackChangeRecords *decimal.Decimal) *schema.CostComponent {
 	return &schema.CostComponent{
-		Name:            "Backtrack",
-		Unit:            "1M change-records",
-		UnitMultiplier:  decimal.NewFromInt(1000000),
-		MonthlyQuantity: backtrackChangeRecords,
+		Name:                 "Backtrack",
+		Unit:                 "1M change-records",
+		UnitMultiplier:       decimal.NewFromInt(1000000),
+		MonthlyQuantity:      backtrackChangeRecords,
+		IgnoreIfMissingPrice: true, // Backtrack is not available in all regions
 		ProductFilter: &schema.ProductFilter{
 			VendorName:    strPtr("aws"),
 			Service:       strPtr("AmazonRDS"),
