@@ -56,16 +56,22 @@ type ArtifactRegistryRepository struct {
 }
 
 // artifactRegistryRepositoryUsageSchema defines a list which represents the usage schema of ArtifactRegistryRepository.
-var artifactRegistryRepositoryUsageSchema = []*schema.UsageItem{
-	{Key: "storage_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{
-		Key: "monthly_egress_data_transfer_gb",
-		DefaultValue: &usage.ResourceUsage{
-			Name:  "monthly_egress_data_transfer_gb",
-			Items: RegionUsageSchema,
+func (r *ArtifactRegistryRepository) CoreType() string {
+	return "ArtifactRegistryRepository"
+}
+
+func (r *ArtifactRegistryRepository) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "storage_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{
+			Key: "monthly_egress_data_transfer_gb",
+			DefaultValue: &usage.ResourceUsage{
+				Name:  "monthly_egress_data_transfer_gb",
+				Items: RegionUsageSchema,
+			},
+			ValueType: schema.SubResourceUsage,
 		},
-		ValueType: schema.SubResourceUsage,
-	},
+	}
 }
 
 // PopulateUsage parses the u schema.UsageData into the ArtifactRegistryRepository.
@@ -105,7 +111,7 @@ func (r *ArtifactRegistryRepository) BuildResource() *schema.Resource {
 
 	return &schema.Resource{
 		Name:           r.Address,
-		UsageSchema:    artifactRegistryRepositoryUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 		CostComponents: costComponents,
 	}
 }
@@ -132,6 +138,7 @@ func (r *ArtifactRegistryRepository) internalEgressComponents() []*schema.CostCo
 			PriceFilter: &schema.PriceFilter{
 				PurchaseOption: strPtr("OnDemand"),
 			},
+			UsageBased: true,
 		})
 	}
 
@@ -158,6 +165,7 @@ func (r *ArtifactRegistryRepository) storageCostComponent() *schema.CostComponen
 			// we ignore the free tier pricing and start at the paid pricing which is at 0.5.
 			StartUsageAmount: strPtr("0.5"),
 		},
+		UsageBased: true,
 	}
 }
 
