@@ -16,10 +16,16 @@ type CloudFunctionsFunction struct {
 	MonthlyOutboundDataGB      *float64 `infracost_usage:"monthly_outbound_data_gb"`
 }
 
-var CloudFunctionsFunctionUsageSchema = []*schema.UsageItem{
-	{Key: "request_duration_ms", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_function_invocations", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_outbound_data_gb", ValueType: schema.Float64, DefaultValue: 0},
+func (r *CloudFunctionsFunction) CoreType() string {
+	return "CloudFunctionsFunction"
+}
+
+func (r *CloudFunctionsFunction) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "request_duration_ms", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_function_invocations", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_outbound_data_gb", ValueType: schema.Float64, DefaultValue: 0},
+	}
 }
 
 func (r *CloudFunctionsFunction) PopulateUsage(u *schema.UsageData) {
@@ -78,6 +84,7 @@ func (r *CloudFunctionsFunction) BuildResource() *schema.Resource {
 						{Key: "description", Value: strPtr("CPU Time")},
 					},
 				},
+				UsageBased: true,
 			},
 			{
 				Name:            "Memory",
@@ -93,6 +100,7 @@ func (r *CloudFunctionsFunction) BuildResource() *schema.Resource {
 						{Key: "description", Value: strPtr("Memory Time")},
 					},
 				},
+				UsageBased: true,
 			},
 			{
 				Name:            "Invocations",
@@ -111,6 +119,7 @@ func (r *CloudFunctionsFunction) BuildResource() *schema.Resource {
 				PriceFilter: &schema.PriceFilter{
 					StartUsageAmount: strPtr("2000000"),
 				},
+				UsageBased: true,
 			},
 			{
 				Name:            "Outbound data transfer",
@@ -129,9 +138,10 @@ func (r *CloudFunctionsFunction) BuildResource() *schema.Resource {
 				PriceFilter: &schema.PriceFilter{
 					StartUsageAmount: strPtr("5"),
 				},
+				UsageBased: true,
 			},
 		},
-		UsageSchema: CloudFunctionsFunctionUsageSchema,
+		UsageSchema: r.UsageSchema(),
 	}
 }
 
