@@ -4,13 +4,13 @@ package aws
 import (
 	"time"
 
-	"github.com/rs/zerolog/log"
+	"github.com/infracost/infracost/internal/logging"
 )
 
 const timeMonth = time.Hour * 24 * 30
 
 func sdkWarn(service string, usageType string, id string, err interface{}) {
-	log.Warn().Msgf("Error estimating %s %s usage for %s: %s", service, usageType, id, err)
+	logging.Logger.Warn().Msgf("Error estimating %s %s usage for %s: %s", service, usageType, id, err)
 }
 
 func intPtr(i int64) *int64 {
